use dialoguer::{Input, MultiSelect, Select};

pub fn select<F>(title: Option<&str>, mut options: Vec<F>) -> F
    where F: ToString
{
    let mut sel = Select::new();
    sel.items(&options);
    sel.default(0);
    if let Some(title) = title {
        sel.with_prompt(title);
    }
    let sel = sel.interact().expect("User didn't enter anything");

    options.remove(sel)
}

pub fn multi_select<F>(title: Option<&str>, options: Vec<F>) -> Vec<F>
    where F: ToString
{
    let mut sel = MultiSelect::new();
    sel.items(&options);
    if let Some(title) = title {
        sel.with_prompt(title);
    }
    let sel = sel.interact().expect("User didn't enter anything");

    options.into_iter()
        .enumerate()
        .filter_map(|(i, v)| sel.contains(&i).then_some(v))
        .collect()
}

pub fn input(title: &str) -> String {
    Input::new()
        .with_prompt(title)
        .interact_text()
        .expect("User didn't enter anything")
}
